@@ -9,7 +9,7 @@ import re
 from abc import abstractmethod
 from ruamel.yaml import safe_load
 from capanno_utils.repo_config import *
-from ...classes.metadata.shared_properties import CodeRepository, WebSite, Person, Publication, Keyword, CallMap
+from ...classes.metadata.shared_properties import CodeRepository, WebSite, Person, Publication, Keyword, CallMap, VideoObject
 from ...classes.metadata.common_functions import _mk_hashes, CommonPropsMixin, SoftwarePropsMixin, get_description_from_file
 from ...classes.metadata.metadata_base import MetadataBase
 
@@ -64,11 +64,11 @@ class WorkflowMetadata(CommonPropsMixin, SoftwarePropsMixin, WorkflowMetadataBas
         ('name', None),
         ('softwareVersion', None),
         ('current', False),
-        ('description', None),
+        ('description', "do I at least work?"),
         ('shortDescription', None),
         ('identifier', None),
         ('metadataStatus', 'Incomplete'),
-        ('workflowStatus', 'Incomplete'),
+        ('workflowStatus', 'Draft'),
         ('workflowLanguage', 'wdl'),
         ('workflowFile', None), # Workflow file.
         ('repoName', None),
@@ -78,6 +78,7 @@ class WorkflowMetadata(CommonPropsMixin, SoftwarePropsMixin, WorkflowMetadataBas
         ('graphStatus', 'Incomplete'),
         ('executable', False),  # if configured to execute on Truwl.
         ('codeRepository', None),
+        ('videos', None),
         ('WebSite', None),
         ('license', None),
         ('contactPoint', None),
@@ -138,6 +139,31 @@ class WorkflowMetadata(CommonPropsMixin, SoftwarePropsMixin, WorkflowMetadataBas
         else:
             self._workflowLanguage = wf_language
 
+    @property
+    def videos(self):
+        return self._videos
+
+    @videos.setter
+    def videos(self, video_list):
+        if video_list:
+            if isinstance(video_list[0], VideoObject):
+                videos = video_list
+            elif isinstance(video_list[0], dict):
+                videos = [VideoObject(**video_dict) for video_dict in video_list]
+            else:
+                raise TypeError(f"Cannot create VideoObject with {video_list}")
+        else:
+            videos = None
+        self._videos = videos
+
+    @property
+    def license(self):
+        return self._license
+
+    @license.setter
+    def license(self, license_identifier):
+        self._license = license_identifier  # use spdx identifiers
+
 
     @classmethod
     def load_from_file(cls, file_path, ignore_empties=False):
